@@ -10,6 +10,7 @@ This package adds the following classes:
 """
 import logging
 import socket
+import django
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import reverse, NoReverseMatch
@@ -59,12 +60,15 @@ class PersonalModule(modules.LinkList):
         Initializes the link list.
         """
         super(PersonalModule, self).init_with_context(context)
-
         current_user = context['request'].user
+        if django.VERSION < (1, 5):
+            current_username = current_user.first_name or current_user.username
+        else:
+            current_username = current_user.get_short_name() or current_user.get_username()
         site_name = get_admin_site_name(context)
 
         # Personalize
-        self.title = _('Welcome,') + ' ' + (current_user.first_name or current_user.username)
+        self.title = _('Welcome,') + ' ' + (current_username)
 
         # Expose links
         self.pages_link = None
@@ -239,7 +243,9 @@ class CacheStatusGroup(modules.Group):
     #: The default title
     title = _("System status")
     #: The default display mode, can be "tabs", "stacked" or "accordion"
-    display = "accordion"
+    display = "stacked"
+    #: Hide by default
+    enabled = False
 
     def init_with_context(self, context):
         """
